<?php
/*
Plugin Name: Animated Image Banners for WPBakery Page Builder
Plugin URI: https://www.infiwebs.com/animated-image-banners/
Author: InfiWebs
Author URI: https://www.infiwebs.com
Version: 1.1.0
Text Domain: infiwebs
Description: This is an addon for WPBakery Page Builder which allows you to create nice looking animated image banners with image, title, description and link to any page / post / anything you wish.
*/
// don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( ! class_exists( 'Infi_Animated_Image_Banners' ) ) {
	class Infi_Animated_Image_Banners {
		// constructor initialization
		function __construct() {
			add_shortcode( 'infi_animated_banners', array( $this, 'animated_banner_shortcode' ) );
			add_action( 'admin_init', array( $this, 'vc_init' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'front_enqueue_scripts' ) );
		}

		// function to enqueue scripts on frontend
		function front_enqueue_scripts() {
			wp_enqueue_style( 'aib-style', plugins_url( '/css/aib-style.css', __FILE__ ) );
		}

		// function to run shortcode
		function animated_banner_shortcode( $atts, $content ) {
			$style = $image = $bg_color = $text_color = $title = $desc = $link = $link_text = $el_class = $font_size_title = $font_size_desc = '';
			extract(
				shortcode_atts(
					array(
						'style'           => 'style01',
						'image'           => '',
						'bg_color'        => '',
						'text_color'      => '',
						'title'           => '',
						'desc'            => '',
						'link'            => '',
						'link_text'       => 'Read More',
						'el_class'        => '',
						'font_size_title' => '',
						'font_size_desc'  => '',
					), $atts
				)
			);
			$html = $href = $target = $style_title = $style_desc = '';
			if ( $font_size_title !== '' ) {
				$style_title .= 'font-size:' . $font_size_title . 'px;';
			}
			if ( $font_size_desc !== '' ) {
				$style_desc .= 'font-size:' . $font_size_desc . 'px;';
			}
			$new_img    = wp_get_attachment_image_src( $image, 'full' );
			$img        = $new_img[0];
			$mask_style = 'background:' . $bg_color . ';';
			if ( $link !== '' ) {
				$href = vc_build_link( $link );
				$href = $href['url'];
				if ( isset( $href['target'] ) ) {
					$target = $href['target'];
				}
			}
			ob_start();
			?>
			<div class="aib-container aib-<?php echo $style; echo ' ' . $el_class;?>">
				<div class="aib-image-banner">
					<div class="aib-figure">
						<img src="<?php echo $img; ?>" />
						<div class="aib-mask" style=" <?php echo $mask_style; ?>"></div>
						<div class="aib-content" style="color:<?php echo $text_color; ?>;">
							<div class="aib-banner-details" style="color:<?php echo $text_color; ?>;">
								<h3 class="aib-title" style=" <?php echo $style_title; ?>"><?php echo $title; ?></h3>
								<p class="aib-desc" style=" <?php echo $style_desc; ?>"><?php echo $desc; ?></p>
							</div>
							<?php if ( $href !== '' ) { ?>
							<div class="aib-link">
								<a href="<?php echo $href; ?>"><?php echo $link_text; ?></a>
							</div>
							<?php } ?>
						</div>
					</div>
				</div>
			</div>

			<?php
			return ob_get_clean();
		}

		// function to register visual composer addon
		function vc_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map(
					array(
						'name'     => __( 'Animated Image Banners' ),
						'base'     => 'infi_animated_banners',
						'class'    => '',
						'icon'     => 'vc_infi_animated_banners',
						'category' => __( 'InfiWebs', 'infiwebs' ),
						'params'   => array(
							array(
								'type'        => 'dropdown',
								'class'       => '',
								'heading'     => __( 'Banner Style', 'infiwebs' ),
								'param_name'  => 'style',
								'admin_label' => true,
								'value'       => array(
									'Style 01' => 'style01',
									'Style 02' => 'style02',
									'Style 03' => 'style03',
									'Style 04' => 'style04',
									'Style 05' => 'style05',
								),
								'description' => __( 'Select the animation type from our pre-designed styles.', 'infiwebs' ),
								'group'       => 'General',
							),
							array(
								'type'        => 'attach_image',
								'class'       => '',
								'heading'     => __( 'Background Image', 'infiwebs' ),
								'param_name'  => 'image',
								'value'       => '',
								'description' => __( 'Select Image you want to use in background.', 'infiwebs' ),
								'group'       => 'General',
							),
							array(
								'type'        => 'colorpicker',
								'class'       => '',
								'heading'     => __( 'Overlay Color', 'infiwebs' ),
								'param_name'  => 'bg_color',
								'value'       => '',
								'description' => __( 'Select the color you want to use as an Overlay layer on your Background Image.', 'infiwebs' ),
								'group'       => 'General',
							),
							array(
								'type'        => 'colorpicker',
								'class'       => '',
								'heading'     => __( 'Text Color', 'infiwebs' ),
								'param_name'  => 'text_color',
								'value'       => '',
								'description' => __( 'Select color you want to use for the text on the Overlay layer.', 'infiwebs' ),
								'group'       => 'General',
							),
							array(
								'type'        => 'textfield',
								'class'       => '',
								'heading'     => __( 'Title', 'infiwebs' ),
								'param_name'  => 'title',
								'admin_label' => true,
								'value'       => '',
								'description' => __( 'Enter the banner title.', 'infiwebs' ),
								'group'       => 'General',
							),
							array(
								'type'        => 'textarea',
								'class'       => '',
								'heading'     => __( 'Short Description', 'infiwebs' ),
								'param_name'  => 'desc',
								'value'       => '',
								'description' => __( 'Enter the short description for this banner.', 'infiwebs' ),
								'group'       => 'General',
							),
							array(
								'type'        => 'vc_link',
								'class'       => '',
								'heading'     => __( 'Banner Link', 'infiwebs' ),
								'param_name'  => 'link',
								'value'       => '',
								'description' => __( 'Enter custom link or select existing post / pages to be linked from this banner.', 'infiwebs' ),
								'group'       => 'General',
							),
							array(
								'type'        => 'textfield',
								'class'       => '',
								'heading'     => __( 'Link Text (Optional)', 'infiwebs' ),
								'param_name'  => 'link_text',
								'value'       => '',
								'description' => __( "Enter the text to be used instead of 'Read More'.", 'infiwebs' ),
								'group'       => 'General',
							),
							array(
								'type'        => 'textfield',
								'class'       => '',
								'heading'     => __( 'Extra Class', 'infiwebs' ),
								'param_name'  => 'el_class',
								'value'       => '',
								'description' => __( 'Enter the class name you would like to use for extra customization.', 'infiwebs' ),
								'group'       => 'General',
							),
							array(
								'type'        => 'textfield',
								'class'       => '',
								'heading'     => __( 'Banner Title Font Size', 'infiwebs' ),
								'param_name'  => 'font_size_title',
								'value'       => '',
								'description' => __( 'Enter the value in numbers. eg. 24', 'infiwebs' ),
								'group'       => 'Advanced',
							),
							array(
								'type'        => 'textfield',
								'class'       => '',
								'heading'     => __( 'Banner Description Font Size', 'infiwebs' ),
								'param_name'  => 'font_size_desc',
								'value'       => '',
								'description' => __( 'Enter the value in numbers. eg. 24', 'infiwebs' ),
								'group'       => 'Advanced',
							),
						), // params -> array
					) // vc_map -> array
				); // vc_map
			} // vc_map existance check
		} // vc_init
	} // Infi_Animated_Image_Banners
	// instantiate the class
	new Infi_Animated_Image_Banners;
}
